<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Globalization.Collation

Windows Runtime (WinRT) APIs for for the `Windows.Globalization.Collation` namespace.

This package provides the `winrt.windows.globalization.collation` module.
